protos/component/arm library Protobuf Definitions
The proto definitions for arm
Classes
- ArmServiceBase
- ArmServiceClient
- GetEndPositionRequest
- GetEndPositionResponse
- GetJointPositionsRequest
- GetJointPositionsResponse
- IsMovingRequest
- IsMovingResponse
- JointAccelerations
- JointPositions
- JointVelocities
- MoveOptions
- MoveOptions specifies kinematic constraints for an arm motion. All fields are optional ceilings; any combination may be set. Every constraint that is set is respected at every point along the executed trajectory. The limiting constraint may change throughout execution.
- MoveThroughJointPositionsRequest
- MoveThroughJointPositionsResponse
- MoveThroughJointPositionsStreamedRequest
- MoveThroughJointPositionsStreamedRequest_Init
- MoveThroughJointPositionsStreamedRequest_TrajectoryBatch
- MoveThroughJointPositionsStreamedResponse
- Streamed back to the client while an arm is performing a streaming move.
- MoveThroughJointPositionsStreamedResponse_BatchAck
-
BatchAck is returned by arm implementations to ack a
TrajectoryBatch. Due to the lack of actionable payload inBatchAck, Arm implementations are not currently obligated to ack every batch, or even any batch. It is currently unspecified whether ack'ing a batch indicates its acceptance, issue to the arm, or completion. These very relaxed requirements may become tighter if and whenBatchAckmessages begin carrying meaningful payloads back to the client. For now, the recommended practice for arm implementors is to ack each batch that has been successfully issued/enqueued to the arm. - MoveToJointPositionsRequest
- MoveToJointPositionsResponse
- MoveToPositionRequest
- Moves an arm to the specified pose that is within the reference frame of the arm. Move request in Motion API has the same behavior except that it performs obstacle avoidance when a world_state message is specified.
- MoveToPositionResponse
- Status
- StopRequest
- StopResponse
- TrajectoryPoint
- One waypoint in a streamed joint-space trajectory.
- TrajectoryPoint_KinematicConstraints
Enums
Constants
-
GetEndPositionRequest$json
→ const Map<
String, Object> -
GetEndPositionResponse$json
→ const Map<
String, Object> -
GetJointPositionsRequest$json
→ const Map<
String, Object> -
GetJointPositionsResponse$json
→ const Map<
String, Object> -
IsMovingRequest$json
→ const Map<
String, Object> -
IsMovingResponse$json
→ const Map<
String, Object> -
JointAccelerations$json
→ const Map<
String, Object> -
JointPositions$json
→ const Map<
String, Object> -
JointVelocities$json
→ const Map<
String, Object> -
MoveOptions$json
→ const Map<
String, Object> -
MoveThroughJointPositionsRequest$json
→ const Map<
String, Object> -
MoveThroughJointPositionsResponse$json
→ const Map<
String, String> -
MoveThroughJointPositionsStreamedRequest$json
→ const Map<
String, Object> -
MoveThroughJointPositionsStreamedRequest_Init$json
→ const Map<
String, Object> -
MoveThroughJointPositionsStreamedRequest_TrajectoryBatch$json
→ const Map<
String, Object> -
MoveThroughJointPositionsStreamedResponse$json
→ const Map<
String, Object> -
MoveThroughJointPositionsStreamedResponse_BatchAck$json
→ const Map<
String, Object> -
MoveToJointPositionsRequest$json
→ const Map<
String, Object> -
MoveToJointPositionsResponse$json
→ const Map<
String, String> -
MoveToPositionRequest$json
→ const Map<
String, Object> -
MoveToPositionResponse$json
→ const Map<
String, String> -
Status$json
→ const Map<
String, Object> -
StopRequest$json
→ const Map<
String, Object> -
StopResponse$json
→ const Map<
String, String> -
TrajectoryPoint$json
→ const Map<
String, Object> -
TrajectoryPoint_KinematicConstraints$json
→ const Map<
String, Object>
Properties
- getEndPositionRequestDescriptor → Uint8List
-
Descriptor for
GetEndPositionRequest. Decode as agoogle.protobuf.DescriptorProto.final - getEndPositionResponseDescriptor → Uint8List
-
Descriptor for
GetEndPositionResponse. Decode as agoogle.protobuf.DescriptorProto.final - getJointPositionsRequestDescriptor → Uint8List
-
Descriptor for
GetJointPositionsRequest. Decode as agoogle.protobuf.DescriptorProto.final - getJointPositionsResponseDescriptor → Uint8List
-
Descriptor for
GetJointPositionsResponse. Decode as agoogle.protobuf.DescriptorProto.final - isMovingRequestDescriptor → Uint8List
-
Descriptor for
IsMovingRequest. Decode as agoogle.protobuf.DescriptorProto.final - isMovingResponseDescriptor → Uint8List
-
Descriptor for
IsMovingResponse. Decode as agoogle.protobuf.DescriptorProto.final - jointAccelerationsDescriptor → Uint8List
-
Descriptor for
JointAccelerations. Decode as agoogle.protobuf.DescriptorProto.final - jointPositionsDescriptor → Uint8List
-
Descriptor for
JointPositions. Decode as agoogle.protobuf.DescriptorProto.final - jointVelocitiesDescriptor → Uint8List
-
Descriptor for
JointVelocities. Decode as agoogle.protobuf.DescriptorProto.final - moveOptionsDescriptor → Uint8List
-
Descriptor for
MoveOptions. Decode as agoogle.protobuf.DescriptorProto.final - moveThroughJointPositionsRequestDescriptor → Uint8List
-
Descriptor for
MoveThroughJointPositionsRequest. Decode as agoogle.protobuf.DescriptorProto.final - moveThroughJointPositionsResponseDescriptor → Uint8List
-
Descriptor for
MoveThroughJointPositionsResponse. Decode as agoogle.protobuf.DescriptorProto.final - moveThroughJointPositionsStreamedRequestDescriptor → Uint8List
-
Descriptor for
MoveThroughJointPositionsStreamedRequest. Decode as agoogle.protobuf.DescriptorProto.final - moveThroughJointPositionsStreamedResponseDescriptor → Uint8List
-
Descriptor for
MoveThroughJointPositionsStreamedResponse. Decode as agoogle.protobuf.DescriptorProto.final - moveToJointPositionsRequestDescriptor → Uint8List
-
Descriptor for
MoveToJointPositionsRequest. Decode as agoogle.protobuf.DescriptorProto.final - moveToJointPositionsResponseDescriptor → Uint8List
-
Descriptor for
MoveToJointPositionsResponse. Decode as agoogle.protobuf.DescriptorProto.final - moveToPositionRequestDescriptor → Uint8List
-
Descriptor for
MoveToPositionRequest. Decode as agoogle.protobuf.DescriptorProto.final - moveToPositionResponseDescriptor → Uint8List
-
Descriptor for
MoveToPositionResponse. Decode as agoogle.protobuf.DescriptorProto.final - statusDescriptor → Uint8List
-
Descriptor for
Status. Decode as agoogle.protobuf.DescriptorProto.final - stopRequestDescriptor → Uint8List
-
Descriptor for
StopRequest. Decode as agoogle.protobuf.DescriptorProto.final - stopResponseDescriptor → Uint8List
-
Descriptor for
StopResponse. Decode as agoogle.protobuf.DescriptorProto.final - trajectoryPointDescriptor → Uint8List
-
Descriptor for
TrajectoryPoint. Decode as agoogle.protobuf.DescriptorProto.final