orientation property
The orientation from the reference frame to the camera.
Implementation
@$pb.TagNumber(2)
$16.Orientation get orientation => $_getN(1);
Implementation
@$pb.TagNumber(2)
set orientation($16.Orientation v) { setField(2, v); }
The orientation from the reference frame to the camera.
@$pb.TagNumber(2)
$16.Orientation get orientation => $_getN(1);
@$pb.TagNumber(2)
set orientation($16.Orientation v) { setField(2, v); }