ModuleStatus class
Inheritance
Object
GeneratedMessage
ModuleStatus
Properties
consecutiveFailures
↔ int
number of times this module has entered the unhealthy state since the last time this module was in the ready state
this will increment if the module is in a restart loop (state transitioning between pending and starting repeatedly)
Resets to zero when the module enters the ready state or is reconfigured.
Useful for detecting modules stuck in a restart loop (like a python module with a syntax error)
getter/setter pair
error
↔ String
when a module transitions to unhealthy, this field is populated with the error that caused the transition.
the error persists until the module reenters the Ready state, guaranteed to be nil in the Ready state
getter/setter pair
eventPlugin
→ EventPlugin?
Subclasses can override this getter to be notified of changes
to protobuf fields.
no setter inherited
hashCode
→ int
Calculates a hash code based on the contents of the protobuf.
no setter inherited
info_
→ BuilderInfo
no setter override
isFrozen
→ bool
Returns true if this message is marked read-only. Otherwise false.
no setter inherited
lastUpdated
↔ Timestamp
updated on every state transition
getter/setter pair
moduleName
↔ String
getter/setter pair
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
state
↔ ModuleStatus_State
getter/setter pair
unknownFields
→ UnknownFieldSet
no setter inherited
Methods
addExtension (Extension extension , Object ? value )
→ void
Adds an extension field value to a repeated field.
inherited
check ()
→ void
inherited
clear ()
→ void
Clears all data that was set in this message.
inherited
clearConsecutiveFailures ()
→ void
clearError ()
→ void
clearExtension (Extension extension )
→ void
Clears an extension field and also removes the extension.
inherited
clearField (int tagNumber )
→ void
Clears the contents of a given field.
inherited
clearLastUpdated ()
→ void
clearModuleName ()
→ void
clearState ()
→ void
clone ()
→ ModuleStatus
Creates a deep copy of the fields in this message.
(The generated code uses mergeFromMessage .)
override
copyWith (void updates (ModuleStatus ) )
→ ModuleStatus
Apply updates to a copy of this message.
override
createEmptyInstance ()
→ ModuleStatus
Creates an empty instance of the same message type as this.
override
createMapField <K , V > (int tagNumber , MapFieldInfo<K , V > fi )
→ Map <K , V >
Creates a Map representing a map field.
inherited
createRepeatedField <T > (int tagNumber , FieldInfo<T > fi )
→ List <T >
Creates List implementing a mutable repeated field.
inherited
ensureLastUpdated ()
→ Timestamp
extensionsAreInitialized ()
→ bool
inherited
freeze ()
→ GeneratedMessage
Make this message read-only.
inherited
getDefaultForField (int tagNumber )
→ dynamic
Returns the default value for the given field.
inherited
getExtension (Extension extension )
→ dynamic
Returns the value of extension.
inherited
getField (int tagNumber )
→ dynamic
Returns the value of the field associated with tagNumber, or the
default value if it is not set.
inherited
getFieldOrNull (int tagNumber )
→ dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber (String fieldName )
→ int ?
inherited
hasConsecutiveFailures ()
→ bool
hasError ()
→ bool
hasExtension (Extension extension )
→ bool
Returns true if a value of extension is present.
inherited
hasField (int tagNumber )
→ bool
Whether this message has a field associated with tagNumber.
inherited
hasLastUpdated ()
→ bool
hasModuleName ()
→ bool
hasRequiredFields ()
→ bool
Whether the message has required fields.
inherited
hasState ()
→ bool
isInitialized ()
→ bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer (List <int > input , [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY ])
→ void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader (CodedBufferReader input , [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY ])
→ void
inherited
mergeFromJson (String data , [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY ])
→ void
Merges field values from data, a JSON object, encoded as described by
GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap (Map <String , dynamic > json , [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY ])
→ void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage (GeneratedMessage other )
→ void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json (Object ? json , {TypeRegistry typeRegistry = const TypeRegistry.empty() , bool ignoreUnknownFields = false , bool supportNamesWithUnderscores = true , bool permissiveEnums = false })
→ void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields (UnknownFieldSet unknownFieldSet )
→ void
inherited
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setExtension (Extension extension , Object value )
→ void
Sets the value of a non-repeated extension field to value.
inherited
setField (int tagNumber , Object value )
→ void
Sets the value of a field by its tagNumber.
inherited
toBuilder ()
→ GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString ()
→ String
Returns a String representation of this message.
inherited
toProto3Json ({TypeRegistry typeRegistry = const TypeRegistry.empty() })
→ Object ?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString ()
→ String
Returns a String representation of this message.
inherited
writeToBuffer ()
→ Uint8List
inherited
writeToCodedBufferWriter (CodedBufferWriter output )
→ void
inherited
writeToJson ()
→ String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap ()
→ Map <String , dynamic >
Returns the JSON encoding of this message as a Dart Map .
inherited