host property

Object host
finalinherited

Starts the Server with the given options. address can be either a String or an InternetAddress, in the latter case it can be a Unix Domain Socket address.

Implementation

final Object host;